@@ -46,13 +46,13 @@ def test_enqueue_copy_rect_2d(ctx_factory, honor_skip=True):
             and ctx.devices[0].platform.name == "Portable Computing Language"
             and get_pocl_version(ctx.devices[0].platform) <= (0, 13)):
         # https://github.com/pocl/pocl/issues/353
-        pytest.skip("POCL's rectangular copies crash")
+        pytest.skip("PoCL's rectangular copies crash")
 
     device = queue.device
     if device.platform.vendor == "The pocl project" \
             and device.type & cl.device_type.GPU:
-        pytest.xfail("rect copies fail on POCL + Nvidia,"
-                "at least the K40, as of pocl 1.6, 2021-01-20")
+        pytest.xfail("rect copies fail on PoCL + Nvidia,"
+                "at least the K40, as of PoCL 1.6, 2021-01-20")
 
     if honor_skip and queue.device.platform.name == "Apple":
         pytest.xfail("Apple's CL implementation crashes on this.")
@@ -77,8 +77,8 @@ def test_enqueue_copy_rect_2d(ctx_factory, honor_skip=True):
     h_ary_in = rng.integers(0, 256, ary_in_shp, dtype=np.uint8)
 
     # Create device buffers
-    d_in_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.product(buf_in_shp))
-    d_out_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.product(buf_out_shp))
+    d_in_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.prod(buf_in_shp))
+    d_out_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.prod(buf_out_shp))
 
     # Copy sub-array (rectangular buffer) from host to device
     cl.enqueue_copy(
@@ -135,13 +135,13 @@ def test_enqueue_copy_rect_3d(ctx_factory, honor_skip=True):
             and ctx.devices[0].platform.name == "Portable Computing Language"
             and get_pocl_version(ctx.devices[0].platform) <= (0, 13)):
         # https://github.com/pocl/pocl/issues/353
-        pytest.skip("POCL's rectangular copies crash")
+        pytest.skip("PoCL's rectangular copies crash")
 
     device = queue.device
     if device.platform.vendor == "The pocl project" \
             and device.type & cl.device_type.GPU:
-        pytest.xfail("rect copies fail on POCL + Nvidia,"
-                "at least the K40, as of pocl 1.6, 2021-01-20")
+        pytest.xfail("rect copies fail on PoCL + Nvidia,"
+                "at least the K40, as of PoCL 1.6, 2021-01-20")
 
     if honor_skip and queue.device.platform.name == "Apple":
         pytest.skip("Apple's CL implementation crashes on this.")
@@ -166,8 +166,8 @@ def test_enqueue_copy_rect_3d(ctx_factory, honor_skip=True):
     h_ary_in = rng.integers(0, 256, ary_in_shp, dtype=np.uint8)
 
     # Create device buffers
-    d_in_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.product(buf_in_shp))
-    d_out_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.product(buf_out_shp))
+    d_in_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.prod(buf_in_shp))
+    d_out_buf = cl.Buffer(ctx, cl.mem_flags.READ_ONLY, size=np.prod(buf_out_shp))
 
     # Copy sub-array (rectangular buffer) from host to device
     cl.enqueue_copy(
